@@ -9,40 +9,34 @@ use DBIx::Class::Factory::Fields;
 
 =head1 NAME
 
-DBIx::Class::Factory — factory-style fixtures for DBIx::Class
+DBIx::Class::Factory - factory-style fixtures for DBIx::Class
 
 =head1 VERSION
 
-Version 0.01
+Version 0.03
 
 =cut
 
-our $VERSION = '0.01_0004';
+our $VERSION = '0.02_0001';
 
 =head1 SYNOPSIS
 
 Create factory:
 
-    {
-        package My::UserFactory;
+    package My::UserFactory;
+    use base qw(DBIx::Class::Factory);
 
-        use base qw(DBIx::Class::Factory);
+    __PACKAGE__->resultset(My::Schema->resultset('User'));
+    __PACKAGE__->fields({
+        name => __PACKAGE__->seq(sub {'User #' . shift}),
+        status => 'new',
+    });
 
-        __PACKAGE__->resultset(My::Schema->resultset('User'));
-        __PACKAGE__->fields({
-            name => __PACKAGE__->seq(sub {'User #' . shift}),
-            status => 'new',
-        });
-    }
+    package My::SuperUserFactory;
+    use base qw(DBIx::Class::Factory);
 
-    {
-        package My::SuperUserFactory;
-
-        use base qw(DBIx::Class::Factory);
-
-        __PACKAGE__->base_factory('My::UserFactory'));
-        __PACKAGE__->field(superuser => 1);
-    }
+    __PACKAGE__->base_factory('My::UserFactory');
+    __PACKAGE__->field(superuser => 1);
 
 Use factory:
 
@@ -193,7 +187,7 @@ Helpers are here for that.
 =item B<callback>
 
 Sometimes you want field value to be calculated everytime fields for object are created.
-Just provide C</callback> as a value in that case.
+Just provide C<callback> as a value in that case.
 
 It will be called with the L<DBIx::Class::Factory::Fields> instance as an argument.
 
@@ -240,17 +234,15 @@ sub seq {
 This helper just calls another factory's L</get_fields> method.
 Thanks to C<DBIx::Class>, the returned data will be used to create a related object.
 
-    {
-        package My::UserFactory;
+    package My::UserFactory;
 
-        use base qw(DBIx::Class::Factory);
+    use base qw(DBIx::Class::Factory);
 
-        __PACKAGE__->resultset(My::Schema->resultset('User'));
-        __PACKAGE__->fields({
-            # create a new city if it's not specified
-            city => __PACKAGE__->related_factory('My::CityFactory'),
-        });
-    }
+    __PACKAGE__->resultset(My::Schema->resultset('User'));
+    __PACKAGE__->fields({
+        # create a new city if it's not specified
+        city => __PACKAGE__->related_factory('My::CityFactory'),
+    });
 
 =cut
 
@@ -328,12 +320,24 @@ sub build {
 
 Creates L<DBIx::Class::Row> object and saves it to a database.
 
+You can also provide the second argument, hashref of options.
+The only option is 'discard_changes', a boolean value which default is true.
+It says whether L<DBIx::Class::Row/discard_changes> should be called on the created object.
+
+    My::UserFactory->create(undef, {discard_changes => 0}); 
+
 =cut
 
 sub create {
-    my ($class, $extra_fields) = @_;
+    my ($class, $extra_fields, $options) = @_;
 
-    return $class->after_create($class->build($extra_fields)->insert());
+    $options = {} unless defined $options;
+    $options->{discard_changes} = 1 unless exists $options->{discard_changes};
+
+    my $row = $class->build($extra_fields)->insert();
+    $row->discard_changes if $options->{discard_changes};
+
+    return $class->after_create($row);
 }
 
 =item B<get_fields_batch>
